--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
-- mapinfo.lua
--

local mapinfo = {
	name        = "Snowbound",
	shortname   = "Snowbound",
	description = "Conquer the hibernating mountain range.",
	author      = "sprang",
	version     = "v1.1",
	--mutator   = "deployment";
	--mapfile   = "", --// location of smf/sm3 file (optional)
	modtype     = 3, --// 1=primary, 0=hidden, 3=map
	depend      = {""},
	replace     = {},

	--startpic   = "", --// deprecated
	--StartMusic = "", --// deprecated

	maphardness     = 400,
	notDeformable   = false,
	gravity         = 130,
	tidalStrength   = 0,
	maxMetal        = 1.4,
	extractorRadius = 50.0,
	voidWater       = false,
	autoShowMetal   = true,


	smf = {
		minheight = 500,
		maxheight = 825,
	},

	resources = {
		--grassBladeTex    	= "grassbladetex.tga",
		--detailTex = "detailtexblurred.bmp",
		--specularTex = "specular.png",
		--splatDetailTex = "splat_Details.png",
		--splatDistrTex = "splat_distr.png",
		--splatDetailNormalDiffuseAlpha = 1,
		--splatDetailNormalTex1 = "splat_normals0.png"; -- texture 82
		--splatDetailNormalTex2 = "splat_normals1.png"; -- texture 86
		--splatDetailNormalTex3 = "splat_normals2.png"; -- texture 269
		--splatDetailNormalTex4 = "splat_normals3.png"; -- texture 379
	},

	splats = {
		texScales = {0.02, 0.02, 0.02, 0.02},
		texMults  = {1.0, 1.0, 1.0, 1.0},
	},

	atmosphere = {

		minWind      = 12,
		maxWind      = 20,

		fogStart     = 0.1,
		--fogEnd       = 1.0,
		fogColor     = {0.7, 0.7, 1.4},

		sunColor     = {1.0, 1.0, 1.0},
		skyColor     = {0.4, 0.4, 1.1},
		skyDir       = {0.0, 0.0, -1.0},
		--skyBox       = "",

		cloudDensity = 0.65,
		cloudColor   = {0.95, 0.95, 1.35},
	},

	grass = {
		bladeWaveScale = 1.0,
		bladeWidth  = 0.32,
		bladeHeight = 4.0,
		bladeAngle  = 1.57,
		bladeColor  = {1.0, 1.0, 1.0},
	},
    
	lighting = {
		--// dynsun
		sunStartAngle = 0.0,
		sunOrbitTime  = 1440.0,
		sunDir        = {0.4, 0.245, 0.15}, --0.195

		--// unit & ground lighting
		groundAmbientColor  = {0.6, 0.6, 0.8},
		groundDiffuseColor  = {0.35, 0.35, 0.35},
		groundSpecularColor = {0.15, 0.15, 0.15},
		groundShadowDensity = 0.95,
		unitAmbientColor    = {0.55, 0.55, 0.95},
		unitDiffuseColor    = {0.35, 0.35, 0.35},
		unitSpecularColor   = {0.5, 0.5, 0.5},
		unitShadowDensity   = 0.95,
		
		specularExponent    = 100.0,
	},
	
	water = {
		damage =  0.0,

		repeatX = 0.0,
		repeatY = 0.0,

		absorb    = {0.004, 0.004, 0.002},
		baseColor = {0.4, 0.6, 0.8},
		minColor  = {0.1, 0.1, 0.23},

		ambientFactor  = 1.3,
		--diffuseFactor  = 1.0,
		specularFactor = 0.5,
		specularPower  = 2.0,

		--planeColor = {0.0, 0.0, 0.0},

		surfaceColor  = {0.65, 0.7, 0.75},
		surfaceAlpha  = 0.01,
		diffuseColor  = {1.0, 1.0, 1.0},
		specularColor = {0.5, 0.5, 0.5},

		fresnelMin   = 0.3,
		fresnelMax   = 1.0,
		fresnelPower = 4.0,

		reflectionDistortion = 1.0,

		blurBase      = 2.0,
		blurExponent = 1.5,

		perlinStartFreq  =  8.0,
		perlinLacunarity = 3.0,
		perlinAmplitude  =  0.9,
		windSpeed = 1.0, --// does nothing yet

		shoreWaves = true,
		forceRendering = false,

		--// undefined == load them from resources.lua!
		--texture =       "",
		--foamTexture =   "",
		--normalTexture = "",
		--caustics = {
		--	"",
		--	"",
		--},
	},

	teams = {
		[0] = {startPos = {x = 300, z = 4820}},
		[1] = {startPos = {x = 4820, z = 300}},
	},

	terrainTypes = {
		[0] = {
			name = "Default",
			hardness = 1.0,
			receiveTracks = true,
			moveSpeeds = {
				tank  = 1.0,
				kbot  = 1.0,
				hover = 1.0,
				ship  = 1.0,
			},
		},
	},

	custom = {
		--[[fog = {
			color    = {1.0, 1.0, 1.0},
			height   = "80%", --// allows either absolue sizes or in percent of map's MaxHeight
			fogatten = 0.003,
		},
		precipitation = {
			density   = 30000,
			size      = 1.5,
			speed     = 50,
			windscale = 1.2,
			texture   = 'LuaGaia/effects/snowflake.png',
		},]]--
        precipitation = {
			weather = "snow",
			density   = 4000, --17500,
			size      = 1.2,
			speed     = 20,
			windscale = 1,
			texture   = 'LuaUI/effects/snowflake.png',
		},
	},
}

--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
-- Helper

local function lowerkeys(ta)
	local fix = {}
	for i,v in pairs(ta) do
		if (type(i) == "string") then
			if (i ~= i:lower()) then
				fix[#fix+1] = i
			end
		end
		if (type(v) == "table") then
			lowerkeys(v)
		end
	end
	
	for i=1,#fix do
		local idx = fix[i]
		ta[idx:lower()] = ta[idx]
		ta[idx] = nil
	end
end

lowerkeys(mapinfo)

--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
-- Map Options

if (Spring) then
	local function tmerge(t1, t2)
		for i,v in pairs(t2) do
			if (type(v) == "table") then
				t1[i] = t1[i] or {}
				tmerge(t1[i], v)
			else
				t1[i] = v
			end
		end
	end

	-- make code safe in unitsync
	if (not Spring.GetMapOptions) then
		Spring.GetMapOptions = function() return {} end
	end
	function tobool(val)
		local t = type(val)
		if (t == 'nil') then
			return false
		elseif (t == 'boolean') then
			return val
		elseif (t == 'number') then
			return (val ~= 0)
		elseif (t == 'string') then
			return ((val ~= '0') and (val ~= 'false'))
		end
		return false
	end

	getfenv()["mapinfo"] = mapinfo
		local files = VFS.DirList("mapconfig/mapinfo/", "*.lua")
		table.sort(files)
		for i=1,#files do
			local newcfg = VFS.Include(files[i])
			if newcfg then
				lowerkeys(newcfg)
				tmerge(mapinfo, newcfg)
			end
		end
	getfenv()["mapinfo"] = nil
end

--------------------------------------------------------------------------------
--------------------------------------------------------------------------------

return mapinfo

--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
